function tau = cnt_parameters(obj,tau)
%CNT_PARAMETERS Frequenzzhler fr kontinuierliche Frequenzmessung konfigurieren
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       tau             Mittelungsdauer
%   output arguments
%       tau             tatschliche Mittelungsdauer
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%
%   SCPI-Befehle 
%       *RST
%       SYSTem:TIMeout
%       [SENSe:]FREQuency:MODE {AUTO | RECiprocal | CONTinuous}
%       INPut[{1|2}]:LEVel[{1|2}][:ABSolute] {<volts> | MINimum | MAXimum | DEFault}
%       [SENSe:]FREQuency:GATE:TIME {<time> | MINimum | MAXimum | DEFault}
%       [SENSe:]FREQuency:GATE:TIME? [{MINimum | MAXimum | DEFault}]
%
%   28.11.2021          T. Weber    

switch obj.Name
    case 'none'
        
    case '53230a' 
        % Preset, Wechselspannungskopplung, hohe Eingangsimpedanz
        fprintf(obj,'*RST');

        % Timeout abschalten
        fprintf(obj,'SYST:TIM INF'); 

        % kontinuierliche Frequenzmessung
        fprintf(obj,'FREQ:MODE RCON'); % CONT-Mode ergibt merkwrdige Artefakte
                
        % Trigger bei Nulldurchgang
        fprintf(obj,'INP:LEV 0.0');
        
        % Mittelungsdauer einstellen
        fprintf(obj,'FREQ:GATE:TIME %f',tau);
        
        % tatschliche Mittelungsdauer auslesen
        fprintf(obj,'FREQ:GATE:TIME?');
        tau = fscanf(obj,'%f');
        
    otherwise
    	error('unsupported frequency counter');
        
end

end
